Discover Packages
github.com/Allexsen/gostl
ds
container
package
Version:
v0.0.0-...-9e67e2f
Opens a new window with list of versions in this module.
Published: Jul 21, 2024
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Container[T any ] interface {
PushBack(T)
PushFront(T)
Back() T
Front() T
PopBack() T
PopFront() T
Clear()
Size() int
Empty() bool
String() string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.