package
Version:
v0.0.0-...-9e67e2f
Opens a new window with list of versions in this module.
Published: Jul 21, 2024
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Queue[T any] struct {
}
func (q *Queue[T]) Back() T
func (q *Queue[T]) Clear()
func (q *Queue[T]) Front() T
func (q *Queue[T]) Pop() T
func (q *Queue[T]) Push(val T)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.